"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PubSub = void 0;
const buffer_1 = require("buffer");
// eslint-disable-next-line @typescript-eslint/no-explicit-any
class PubSub {
    constructor(key, ipfs) {
        this.key = key;
        this.ipfs = ipfs;
    }
    encode(data) {
        return buffer_1.Buffer.from(JSON.stringify(data));
    }
    decode(data) {
        return JSON.parse(buffer_1.Buffer.from(data).toString());
    }
    getTopic(topic) {
        return `${this.key}${topic ? '/' + topic : ''}`;
    }
    publish(key = '.', data) {
        return this.ipfs.pubsub.publish(this.getTopic(key), this.encode(data));
    }
    subscribe(key = '.', listener) {
        return this.ipfs.pubsub.subscribe(this.getTopic(key), (msg) => {
            listener(this.decode(msg.data), msg.from);
        });
    }
    unsubscribe(key = '.') {
        return this.ipfs.pubsub.unsubscribe(this.getTopic(key));
    }
}
exports.PubSub = PubSub;
//# sourceMappingURL=pubsub.js.map