import type { IPFS } from "ipfs-core";
import { Shard, Data } from './shard';
import { Crypto } from "@dstack-js/crypto";
export declare type ShardMap = {
    [key: string]: Shard;
};
export declare class Store {
    private ipfs;
    key: string;
    private publicKey;
    private privateKey?;
    private shardMap;
    crypto: Crypto;
    private replication;
    /**
     * stores shards linked to unique keys
     * @param ipfs IPFS instance
     * @param key unique key for store, used for shard replication
     * @param publicKey RSA Public Key, required for verifying data
     * @param privateKey RSA Private Key, required only if you need to add data
     */
    constructor(ipfs: IPFS, key: string, publicKey: string, privateKey?: string | undefined);
    private getSignatureData;
    /**
     * add data to store
     * @param key unique key for data to be stored
     * @param data to be stored
     * @returns shard
     */
    add(key: string, data: Data, replicate?: boolean): Promise<Shard>;
    /**
     * get data from store
     * @param key unique key
     * @returns shard
     */
    get(key: string): Promise<Shard | null>;
    close(): Promise<void>;
}
